@@ -66,7 +66,19 @@ $(function(){
       },
       position: { my: "right top", at: "right bottom", of: "#search div" },
       source: [
-          PREDEFINED
+          {
+              category: "Syntax",
+              value: "# single-line comment",
+              url: "/language/syntax#Single-line_comments"
+          }, {
+              category: "Syntax",
+              value: "#` multi-line comment",
+              url: "/language/syntax#Multi-line_/_embedded_comments"
+          }, {
+              category: "Signature",
+              value: ";; (long name)",
+              url: "/type/Signature#index-entry-Long_Names"
+          },
           ITEMS
       ],
       select: function (event, ui) { window.location.href = ui.item.url; },
